@@ -11,8 +11,6 @@ use Perl::ToPerl6::Transformer qw{};
 use Perl::ToPerl6::Utils qw{ :characters };
 use overload ( q{""} => 'to_string' );
 
-our $VERSION = '0.03';
-
 #-----------------------------------------------------------------------------
 
 sub new {
@@ -77,8 +75,13 @@ sub to_string {
     my $prototype = "# Globals\n";
 
     $prototype .= $prefix;
-    $prototype .= q{severity = };
-    $prototype .= $configuration->severity();
+    $prototype .= q{necessity = };
+    $prototype .= $configuration->necessity();
+    $prototype .= "\n";
+
+    $prototype .= $prefix;
+    $prototype .= q{detail = };
+    $prototype .= $configuration->detail();
     $prototype .= "\n";
 
     $prototype .= $prefix;
@@ -87,13 +90,13 @@ sub to_string {
     $prototype .= "\n";
 
     $prototype .= $prefix;
-    $prototype .= q{only = };
-    $prototype .= $configuration->only();
+    $prototype .= q{in-place = };
+    $prototype .= $configuration->in_place();
     $prototype .= "\n";
 
     $prototype .= $prefix;
-    $prototype .= q{allow-unsafe = };
-    $prototype .= $configuration->unsafe_allowed();
+    $prototype .= q{only = };
+    $prototype .= $configuration->only();
     $prototype .= "\n";
 
     $prototype .= $prefix;
@@ -142,11 +145,11 @@ sub to_string {
     $prototype .= "\n";
 
     foreach my $item (qw<
-        color-severity-highest
-        color-severity-high
-        color-severity-medium
-        color-severity-low
-        color-severity-lowest
+        color-necessity-highest
+        color-necessity-high
+        color-necessity-medium
+        color-necessity-low
+        color-necessity-lowest
         >) {
         ( my $accessor = $item ) =~ s/ - /_/gmsx;
         $prototype .= $prefix;
@@ -190,8 +193,7 @@ sub _proto_format {
 [%p]
 ${prefix}set_themes                         = %t
 ${prefix}add_themes                         =
-${prefix}severity                           = %s
-${prefix}maximum_transformations_per_document    = %v
+${prefix}necessity                           = %s
 %{\\n%\\x7b# \\x7df\\n${prefix}%n = %D\\n}O%{${prefix}Cannot programmatically discover what parameters this transformer takes.\\n}U
 END_OF_FORMAT
 
@@ -229,7 +231,7 @@ to change without notice.
 
 =over
 
-=item C<< new( -transformers => \@POLICY_OBJECTS ) >>
+=item C<< new( -transformers => \@TRANSFORMER_OBJECTS ) >>
 
 Returns a reference to a new C<Perl::ToPerl6::ProfilePrototype> object.
 
@@ -255,7 +257,7 @@ L<"OVERLOADS"> for more information.
 When a
 L<Perl::ToPerl6::ProfilePrototype|Perl::ToPerl6::ProfilePrototype> is
 evaluated in string context, it produces a multi-line summary of the
-transformer name, default themes, and default severity for each
+transformer name, default themes, and default necessity for each
 L<Perl::ToPerl6::Transformer|Perl::ToPerl6::Transformer> object that was given to
 the constructor of this C<ProfilePrototype>.  If the Transformer supports
 an additional parameters, they will also be listed (but
