@@ -23,8 +23,6 @@ use Perl::ToPerl6::TransformerParameter::Behavior::StringList;
 use Perl::ToPerl6::Utils qw{ :characters &interpolate };
 use Perl::ToPerl6::Utils::DataConversion qw{ &defined_or_empty };
 
-our $VERSION = '0.03';
-
 Readonly::Scalar our $NO_DESCRIPTION_AVAILABLE => 'No description available.';
 
 #-----------------------------------------------------------------------------
@@ -374,7 +372,7 @@ C<%d>.  Takes a parameter of a prefix for the beginning of each line.
 
 =head1 SEE ALSO
 
-L<Perl::ToPerl6::DEVELOPER/"MAKING YOUR POLICY CONFIGURABLE">
+L<Perl::ToPerl6::DEVELOPER/"MAKING YOUR TRANSFORMER CONFIGURABLE">
 
 
 =head1 AUTHOR
